@@ -3,7 +3,7 @@ import json
 from django.http import Http404, HttpResponse
 from django.views.decorators.cache import never_cache
 
-from cached_hitcount.utils import get_ip, get_hitcount_cache, is_cached_hitcount_enabled, is_bot_request
+from cached_hitcount.utils import get_ip, get_hitcount_cache, is_cached_hitcount_enabled, is_bot_request, using_memcache
 from cached_hitcount.models import BlacklistIP
 from cached_hitcount.settings import CACHED_HITCOUNT_CACHE_TIMEOUT, CACHED_HITCOUNT_EXCLUDE_IP_ADDRESS, CACHED_HITCOUNT_EXCLUDE_BOTS, CACHED_HITCOUNT_LOCK_KEY
 from cached_hitcount.decorators import conditional_csrf_exempt
@@ -65,7 +65,7 @@ def update_hit_count_ajax(request):
     '''
 
     # make sure this is an ajax request
-    if not is_cached_hitcount_enabled or not request.is_ajax():
+    if not is_cached_hitcount_enabled() or not using_memcache() or not request.is_ajax():
         raise Http404()
 
     if request.method == "GET":
